SigningKey class

The SigningKey class provides methods to generate and manage Ed25519 signing keys.

This class supports creating signing keys from a mnemonic, entropy, or generating new keys. It also provides methods to sign data and retrieve the corresponding public key.

Constructors

SigningKey.fromSeed({required Uint8List seed})
Creates a SigningKey from a provided seed.
SigningKey.fromValidKey({required Uint8List bytes})
Creates a SigningKey from valid key bytes.

Properties

bytes List<int>
Gets the key bytes.
no setter
hashCode int
The hash code for this object.
no setterinherited
publicKey PublicKey
Gets the corresponding public key.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(List<int> data) List<int>
Signs the given data.
toString() String
A string representation of this object.
inherited
verify(List<int> data, List<int> signature) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromEntropy(String entropy) Future<SigningKey>
Creates a SigningKey from entropy.
fromMnemonic(String mnemonic) Future<SigningKey>
Creates a SigningKey from a mnemonic phrase.
generate() Future<SigningKey>
Generates a new SigningKey.