fromEntropy static method

Future<SigningKey> fromEntropy(
  1. String entropy
)

Creates a SigningKey from entropy.

The entropy is used to derive a seed, which is then used to create the signing key.

  • Parameter entropy: The entropy string.
  • Returns: A Future that completes with the SigningKey.

Implementation

static Future<SigningKey> fromEntropy(final String entropy) async {
  final bip44 = Bip44.fromEntropy(entropy);
  return SigningKey._(
    ed25519.SigningKey.fromSeed(
      Uint8List.fromList(
        await bip44.deriveKey(),
      ),
    ),
  );
}