Bip44 class
A class that provides functionality for BIP-44 hierarchical deterministic wallets.
BIP-44 is a standard for deterministic wallets that allows for the generation of multiple key pairs from a single seed phrase (mnemonic). This class supports generating a new mnemonic, deriving keys from a mnemonic, and converting between entropy and mnemonic.
Example usage:
// Generate a new BIP-44 wallet
final wallet = Bip44.generate();
// Derive a key for a specific address index
final key = await wallet.deriveKey(addressIndex: 0);
// Get the mnemonic for the wallet
final mnemonic = wallet.mnemonic;
See also:
Constructors
- Bip44.fromEntropy(String entropy)
-
Creates a Bip44 instance from the given
entropy.factory - Bip44.fromMnemonic(String mnemonic)
-
Creates a Bip44 instance from the given
mnemonic.factory - Bip44.generate({int strength = _defaultMnemonicStrength})
-
Generates a new Bip44 instance with a random mnemonic.
factory
Properties
Methods
-
deriveKey(
{int addressIndex = 0, String password = ''}) → Future< List< int> > -
Derives a key for the given
addressIndexandpassword. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited