SigningKey class
The SigningKey class provides methods to generate and manage Ed25519 signing keys.
This class supports creating signing keys from a mnemonic, entropy, or generating new keys. It also provides methods to sign data and retrieve the corresponding public key.
Constructors
- SigningKey.fromSeed({required Uint8List seed})
-
Creates a
SigningKeyfrom a provided seed. - SigningKey.fromValidKey({required Uint8List bytes})
-
Creates a
SigningKeyfrom valid key bytes.
Properties
Methods
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromEntropy(
String entropy) → Future< SigningKey> -
Creates a
SigningKeyfrom entropy. -
fromMnemonic(
String mnemonic) → Future< SigningKey> -
Creates a
SigningKeyfrom a mnemonic phrase. -
generate(
) → Future< SigningKey> -
Generates a new
SigningKey.